#!/bin/bash

function make_arch_package() {
    version=$1

    cat > PKGBUILD << EOF
pkgname=live-system
pkgver=$version
pkgrel=1
pkgdesc='Live DVD/USB build and install tool'
arch=('any')
url='https://fox-echo.info/live-system/'
license=('CeCILL')
depends=('dosfstools' 'gptfdisk' 'grub' 'squashfs-tools' 'busybox')
source=(\$pkgname-\$pkgver.tar.gz)
sha256sums=(SKIP)

package() {
    cd \$pkgname-\$pkgver
    make install PREFIX=/usr DESTDIR="\$pkgdir" BINDIR=/usr/bin DOCDIR=/usr/share/doc
    mv "\$pkgdir"/usr/share/doc/\$pkgname-\$pkgver "\$pkgdir"/usr/share/doc/\$pkgname
    install -Dm644 "\$srcdir"/\$pkgname-\$pkgver/doc/License_CeCILL_V2.1-en.txt "\$pkgdir"/usr/share/licenses/\$pkgname/LICENSE
}
EOF
    makepkg -f
    rm -rf PKGBUILD src pkg
    mv live-system-$version-1-any.pkg.tar.* arch/
}


function make_slackware_package() {
    version=$1

    tar -zxvf live-system-$version.tar.gz; cd live-system-$version
    make install DESTDIR=pack PREFIX=/usr
    mkdir pack/install
    cat > pack/install/slack-desc << EOF
live-system: live-system (Live DVD/USB build and install tool)
live-system:
live-system: Live-System is a live DVD / USB / NFS build and install tool
live-system: written for Arch, Debian, Slackware64 and Ubuntu Linux.
live-system: The ISO can be flashed to an USB key and supports UEFI as well as
live-system: legacy (BIOS) booting.
live-system: It is an unintrusive solution that uses system kernel, core tools
live-system: and boot scripts and doesn't need any specific configuration.
live-system: The live system supports persistent data and WiFi configuration.
live-system:
live-system:
EOF
    #Slackware 'makepkg' faker
    sudo chown -R root:root pack
    cd pack; find ./ | LC_COLLATE=C sort | sed '2,$s,^\./,,' | tar --no-recursion -T - -cvf - | xz --threads=0 -c > ../../slackware/live-system-$version-noarch-orig.txz; cd ..
    sudo chown -R $USER pack
    cd ..; rm -rf live-system-$version
}


function make_debian_package() {
    version=$1

    arch=$(uname -m); if [ "$arch" == "x86_64" ]; then arch="amd64"; else arch="arm64"; fi
    tar -zxvf live-system-$version.tar.gz; cd live-system-$version
    make install DESTDIR=pack PREFIX=/usr
    mkdir pack/DEBIAN
    cat > pack/DEBIAN/control << EOF
Package: live-system
Version: $version
Architecture: all
Depends: dosfstools, gdisk, grub-efi-amd64-bin, initramfs-tools, genisoimage, squashfs-tools, busybox
Maintainer: Frank Endres <frankendres@tuxfamily.org>
Description: Live DVD/USB build and install tool
Homepage: https://https://fox-echo.info/live-system/
EOF
    find pack -type d -exec chmod 755 {} \;
    sudo chown -R root:root pack
    sudo dpkg-deb --build pack && mv pack.deb ../debian/live-system_"$version"_all.deb
    sudo chown -R $USER pack
    cd ..; rm -rf live-system-$version
}


changelog_version=$(cat doc/ChangeLog.md | grep "## " | head -n1 | sed 's/.* - v//')
dir_version=$(basename $(pwd) | rev | cut -f1 -d- |rev)
if [ "$dir_version" != "$changelog_version" ]; then
    echo "version error: dir=$dir_version, doc/ChangeLog.md=$changelog_version" >&2
    exit 1
fi
version=$dir_version

rm -rf releases www
cd ..; tar -czvf live-system-$version.tar.gz live-system-$version; cd live-system-$version
mkdir -p releases/{arch,slackware,debian}
mv ../live-system-$version.tar.gz releases/

cd releases
make_arch_package $version
make_slackware_package $version
make_debian_package $version
cd ..

gpg --detach-sign --sign $(ls releases/*.tar.gz)
gpg --detach-sign --sign $(ls releases/arch/*)
gpg --detach-sign --sign $(ls releases/debian/*)
gpg --detach-sign --sign $(ls releases/slackware/*)

if [ "$1" == "-u" ]; then
    ssh -4 -t root@fox-echo.info "mkdir -p /var/www/fox-echo.info/live-system"
    scp -4 -r releases/* root@fox-echo.info:/var/www/fox-echo.info/live-system/res/
    sitegen.sh
    scp -4 www/* root@fox-echo.info:/var/www/fox-echo.info/live-system/
fi

